@@ -1,3 +1,4 @@
+from .neighbourhoods import Neighbourhood
 from .resource import Resource, SimpleResource
 
 
@@ -38,6 +39,10 @@ class Force(Resource):
         self._resource_cache[method] = objs
         return objs
 
+    def get_neighbourhood(self, neighbourhood_id, **attrs):
+        return Neighbourhood(self.api, force=self, id=neighbourhood_id,
+                             **attrs)
+
     @property
     def senior_officers(self):
         return self._get_resource(self.SeniorOfficer, 'people')
